| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.FraudDetector.Types.FilterCondition
Description
Synopsis
Documentation
data FilterCondition Source #
A conditional statement for filtering a list of past predictions.
See: newFilterCondition smart constructor.
Constructors
| FilterCondition' | |
Instances
newFilterCondition :: FilterCondition Source #
Create a value of FilterCondition with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:value:FilterCondition', filterCondition_value - A statement containing a resource property and a value to specify filter
condition.
filterCondition_value :: Lens' FilterCondition (Maybe Text) Source #
A statement containing a resource property and a value to specify filter condition.